==> wikitty-api-3.11-sources.jar: org/nuiton/wikitty/query/WikittyQueryMaker.java <==
package org.nuiton.wikitty.query;

/*
 * #%L
 * Wikitty :: api
 * $Id: WikittyQueryMaker.java 1545 2013-02-24 01:41:10Z bpoussin $
 * $HeadURL: http://svn.nuiton.org/wikitty/tags/wikitty-3.11/wikitty-api/src/main/java/org/nuiton/wikitty/query/WikittyQueryMaker.java $
 * %%
 * Copyright (C) 2009 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */


import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Classe concrete de construction de requete pour la documentation voir
 * {@link WikittyQueryMakerAbstract}
 *
 * @author poussin
 * @version $Revision: 1545 $
 *
 * Last update: $Date: 2013-02-24 02:41:10 +0100 (Sun, 24 Feb 2013) $
 * by : $Author: bpoussin $
 */
public class WikittyQueryMaker extends WikittyQueryMakerAbstract<WikittyQueryMaker> {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(WikittyQueryMaker.class);

    public WikittyQueryMaker() {
        super();
    }

    public WikittyQueryMaker(WikittyQuery query) {
        super(query);
    }

    @Override
    protected WikittyQueryMaker asM() {
        return this;
    }

}

==> wikitty-api-3.12-sources.jar: org/nuiton/wikitty/query/WikittyQueryMaker.java <==
package org.nuiton.wikitty.query;

/*
 * #%L
 * Wikitty :: api
 * %%
 * Copyright (C) 2009 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */


import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Classe concrete de construction de requete pour la documentation voir
 * {@link WikittyQueryMakerAbstract}
 *
 * @author poussin
 * @version $Revision$
 *
 * Last update: $Date$
 * by : $Author$
 */
public class WikittyQueryMaker extends WikittyQueryMakerAbstract<WikittyQueryMaker> {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(WikittyQueryMaker.class);

    public WikittyQueryMaker() {
        super();
    }

    public WikittyQueryMaker(WikittyQuery query) {
        super(query);
    }

    @Override
    protected WikittyQueryMaker asM() {
        return this;
    }

}
